==> dde-cooperation_1.1.2.tar.xz: BUILD/translations/dfmplugin-deliver/cooperation-transfer_km_KH.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="km_KH">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/cooperationplugin.cpp" line="60"/>
        <source>File transfer settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/cooperationplugin.cpp" line="62"/>
        <source>Settings</source>
        <comment>button</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::CooperationMenuScene</name>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/menu/cooperationmenuscene.cpp" line="32"/>
        <source>File transfer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::CooperationPlugin</name>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/cooperationplugin.cpp" line="55"/>
        <source>File transfer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::FileTransferSettingsDialog</name>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="150"/>
        <source>File transfer settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="164"/>
        <source>Everyone in the same LAN</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="165"/>
        <source>Only those who are collaborating are allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="166"/>
        <source>Not allow</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="170"/>
        <source>Allows the following users to send files to me</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="171"/>
        <source>File save location</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> dde-cooperation_1.1.13.tar.xz: BUILD/translations/dfmplugin-deliver/cooperation-transfer_km_KH.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="km_KH">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/cooperationplugin.cpp" line="60"/>
        <source>File transfer settings</source>
        <translation>ការកំណត់​ប្រតិបត្តិ​ការផ្ទះ​ឯកសារ</translation>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/cooperationplugin.cpp" line="62"/>
        <source>Settings</source>
        <comment>button</comment>
        <translation>កំណត់​ទំហំ</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::CooperationMenuScene</name>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/menu/cooperationmenuscene.cpp" line="32"/>
        <source>File transfer</source>
        <translation>ការផ្ទះ​ឯកសារ</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::CooperationPlugin</name>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/cooperationplugin.cpp" line="55"/>
        <source>File transfer</source>
        <translation>ការផ្ទះ​ឯកសារ</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::FileTransferSettingsDialog</name>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="150"/>
        <source>File transfer settings</source>
        <translation>ការកំណត់​ប្រតិបត្តិ​ការផ្ទះ​ឯកសារ</translation>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="164"/>
        <source>Everyone in the same LAN</source>
        <translation>អ្នកទាំងអ្នក​ដែល​នៅ​ក្នុង​ប្រព័ន្ធប្រតិបត្តិ​ដែល​ស្រដៀង​នឹង​LAN</translation>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="165"/>
        <source>Only those who are collaborating are allowed</source>
        <translation>តែអ្នកដែលកំពុង​ធ្វើ​ការ​សហការ​តែមួយ​ទេ​ដែល​អាច​ធ្វើ​បាន</translation>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="166"/>
        <source>Not allow</source>
        <translation>មិន​អនុញ្ញាត</translation>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="170"/>
        <source>Allows the following users to send files to me</source>
        <translation>អនុញ្ញាត​អ្នក​ដែល​បាន​បញ្ជាក់​នៅ​ក្រោម​នេះ​ទៅ​ផ្ទះ​ឯកសារ​ដល់​ខ្ញុំ</translation>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="171"/>
        <source>File save location</source>
        <translation>ទីតាំង​ផ្ទះ​ឯកសារ</translation>
    </message>
</context>
</TS>
